%{?mingw_package_header}

%global pkgname vulkan

%global glslang_commit 715c353a15836e5ae192a64a4cf54e2ce7e8d66a
%global SPIRVHeaders_commit 061097878467b8e040fbf153a837d844ef9f9f96
%global SPIRVTools_commit 5834719fc17d4735fce0102738b87b70255cfd5f

Name:          mingw-%{pkgname}
Version:       1.0.65.1
Release:       2%{?dist}
Summary:       MinGW Windows %{pkgname} library

License:       ASL 2.0
BuildArch:     noarch
URL:           https://github.com/KhronosGroup
Source0:       https://github.com/KhronosGroup/Vulkan-LoaderAndValidationLayers/archive/sdk-%{version}/Vulkan-LoaderAndValidationLayers-sdk-%{version}.tar.gz
Source1:       https://github.com/KhronosGroup/glslang/archive/%{glslang_commit}/glslang-%{glslang_commit}.tar.gz
Source2:       https://github.com/KhronosGroup/SPIRV-Headers/archive/%{SPIRVHeaders_commit}/SPIRV-Headers-%{SPIRVHeaders_commit}.tar.gz
Source3:       https://github.com/KhronosGroup/SPIRV-Tools/archive/%{SPIRVTools_commit}/SPIRV-Tools-%{SPIRVTools_commit}.tar.gz

# Fix build with mingw
Patch0:        vulkan_mingw.patch
# Build static SPIRV-Tools libraries
Patch1:        SPIRV-Tools_staticlib.patch

BuildRequires: cmake
BuildRequires: gcc-c++

BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++
BuildRequires: mingw32-winpthreads
BuildRequires: mingw32-winpthreads-static

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
BuildRequires: mingw64-winpthreads
BuildRequires: mingw64-winpthreads-static


%description
MinGW Windows %{pkgname} library.


%package -n mingw32-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw32-%{pkgname}
MinGW Windows %{pkgname} library.


%package -n mingw64-%{pkgname}
Summary:       MinGW Windows %{pkgname} library

%description -n mingw64-%{pkgname}
MinGW Windows %{pkgname} library.


%{?mingw_debug_package}


%prep
%setup -q -n Vulkan-LoaderAndValidationLayers-sdk-%{version}
%patch0 -p1

mkdir -p build/ external/glslang external/spirv-tools/ external/spirv-tools/external/spirv-headers
tar -xf %{SOURCE1} -C external/glslang --strip 1
tar -xf %{SOURCE2} -C external/spirv-tools/external/spirv-headers --strip 1
tar -xf %{SOURCE3} -C external/spirv-tools --strip 1

pushd external/spirv-tools
%patch1 -p1
popd


%build
pushd external/glslang/

mkdir build_native
pushd build_native
%cmake ..
make %{?_smp_mflags}
popd

%mingw_cmake
%mingw_make %{?_smp_mflags}
popd

pushd external/spirv-tools/
%mingw_cmake
%mingw_make %{?_smp_mflags}
popd

mkdir build_win32
pushd build_win32
%mingw32_cmake \
  -DBUILD_TESTS=OFF \
  -DBUILD_VKJSON=OFF \
  -DGLSLANG_SPIRV_INCLUDE_DIR=../external/glslang/ \
  -DGLSLANG_LIB=../external/glslang/build_win32/glslang/libglslang.a \
  -DOGLCompiler_LIB=../external/glslang/build_win32/OGLCompilersDLL/libOGLCompiler.a \
  -DOSDependent_LIB=../external/glslang/build_win32/glslang/OSDependent/Windows/libOSDependent.a \
  -DHLSL_LIB=../external/glslang/build_win32/hlsl/libHLSL.a \
  -DSPIRV_LIB=../external/glslang/build_win32/SPIRV/libSPIRV.a \
  -DSPIRV_REMAPPER_LIB=../external/glslang/build_win32/SPIRV/libSPVRemapper.a \
  -DGLSLANG_VALIDATOR=../external/glslang/build_native/StandAlone/glslangValidator \
  -DSPIRV_TOOLS_INCLUDE_DIR=../external/spirv-tools/include/ \
  -DSPIRV_TOOLS_LIB=../external/spirv-tools/build_win32/source/libSPIRV-Tools.a \
  -DSPIRV_TOOLS_OPT_LIB=../external/spirv-tools/build_win32/source/opt/libSPIRV-Tools-opt.a
%mingw32_make %{?_smp_mflags}
popd

mkdir build_win64
pushd build_win64
%mingw64_cmake \
  -DBUILD_TESTS=OFF \
  -DBUILD_VKJSON=OFF \
  -DGLSLANG_SPIRV_INCLUDE_DIR=../external/glslang/ \
  -DGLSLANG_LIB=../external/glslang/build_win64/glslang/libglslang.a \
  -DOGLCompiler_LIB=../external/glslang/build_win64/OGLCompilersDLL/libOGLCompiler.a \
  -DOSDependent_LIB=../external/glslang/build_win64/glslang/OSDependent/Windows/libOSDependent.a \
  -DHLSL_LIB=../external/glslang/build_win64/hlsl/libHLSL.a \
  -DSPIRV_LIB=../external/glslang/build_win64/SPIRV/libSPIRV.a \
  -DSPIRV_REMAPPER_LIB=../external/glslang/build_win64/SPIRV/libSPVRemapper.a \
  -DGLSLANG_VALIDATOR=../external/glslang/build_native/StandAlone/glslangValidator \
  -DSPIRV_TOOLS_INCLUDE_DIR=../external/spirv-tools/include/ \
  -DSPIRV_TOOLS_LIB=../external/spirv-tools/build_win64/source/libSPIRV-Tools.a \
  -DSPIRV_TOOLS_OPT_LIB=../external/spirv-tools/build_win64/source/opt/libSPIRV-Tools-opt.a
%mingw64_make %{?_smp_mflags}
popd


%install
%mingw32_make -C build_win32 DESTDIR=%{buildroot} install
%mingw64_make -C build_win64 DESTDIR=%{buildroot} install
install -Dpm 0755 build_win32/icd/libVkICD_mock_icd.dll %{buildroot}%{mingw32_bindir}/libVkICD_mock_icd.dll
install -Dpm 0755 build_win64/icd/libVkICD_mock_icd.dll %{buildroot}%{mingw64_bindir}/libVkICD_mock_icd.dll

rm -rf %{buildroot}%{mingw32_sysconfdir}
rm -rf %{buildroot}%{mingw64_sysconfdir}
rm -f %{buildroot}%{mingw32_bindir}/smoketest.exe
rm -f %{buildroot}%{mingw64_bindir}/smoketest.exe


%files -n mingw32-%{pkgname}
%license LICENSE.txt COPYRIGHT.txt
%{mingw32_bindir}/libvulkan-1.dll
%{mingw32_bindir}/libVkLayer_*.dll
%{mingw32_bindir}/libVkICD_mock_icd.dll
%{mingw32_bindir}/vulkaninfo.exe
%{mingw32_includedir}/vulkan/
%{mingw32_libdir}/libvulkan.dll.a
%{mingw32_libdir}/libVkLayer_*.dll.a
%{mingw32_libdir}/pkgconfig/vulkan.pc

%files -n mingw64-%{pkgname}
%license LICENSE.txt COPYRIGHT.txt
%{mingw64_bindir}/libvulkan-1.dll
%{mingw64_bindir}/libVkLayer_*.dll
%{mingw64_bindir}/libVkICD_mock_icd.dll
%{mingw64_bindir}/vulkaninfo.exe
%{mingw64_includedir}/vulkan/
%{mingw64_libdir}/libvulkan.dll.a
%{mingw64_libdir}/libVkLayer_*.dll.a
%{mingw64_libdir}/pkgconfig/vulkan.pc


%changelog
* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.65.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Dec 19 2017 Sandro Mani <manisandro@gmail.com> - 1.0.65.1-1
- Update to 1.0.65.1

* Thu Oct 12 2017 Sandro Mani <manisandro@gmail.com> - 1.0.61.1-1
- Initial package
